@@ -8,6 +8,10 @@ from . import cjpeglib
 
 class CJpegLib:
 
+    @classmethod
+    def jpeg_lib_version(cls):
+        return cls.get().jpeg_lib_version()
+
     @classmethod
     def read_jpeg_info(cls, srcfile, dct_dims, image_dims, num_components, samp_factor, jpeg_color_space):
         status = cls.get().read_jpeg_info(cls.cstr(srcfile), dct_dims, image_dims, num_components, samp_factor, jpeg_color_space)
@@ -79,11 +83,19 @@ class CJpegLib:
     @classmethod
     def get_version(cls):
         return cls.version
-
+    @classmethod
+    def _versions(cls):
+        so_files = [f for f in os.listdir(cjpeglib.__path__[0]) if re.fullmatch(f'cjpeglib_.*\..*\.so', f)]
+        return so_files
+    @classmethod
+    def versions(cls):
+        vs = [re.search(f'cjpeg_[^.]*\..*\.so', f) for f in cls._versions()]
+        vs = [v[0] for v in vs if v]
+        return vs
     @classmethod
     def _bind_lib(cls, version='6b'):
         # path of the library
-        so_files = [f for f in os.listdir(cjpeglib.__path__[0]) if re.fullmatch(f'cjpeglib_{version}\..*\.so', f)]
+        so_files = [f for f in cls._versions() if re.fullmatch(f'cjpeglib_{version}\..*\.so', f)]
         try:
             so_file = so_files[0]
         except:
