@@ -9,11 +9,23 @@ extern "C" {
 #include <stdlib.h>
 #include <string.h>
 
-#ifdef USE_TURBO
-#include <jmorecfg.h>
-#endif
+#include "cjpeglib.h"
 
-#include <jpeglib.h>
+#include "vjpeglib.h"
+// #if LIBVERSION == 60
+// #include "6b/jpeglib.h"
+// #elif LIBVERSION == 80
+// #include "8d/jpeglib.h"
+// #elif LIBVERSION == 210
+// #include "turbo210/jpeglib.h"
+// #else
+// // intentional syntax error
+// Not supported version.
+// #endif
+
+//#ifdef USE_TURBO
+//#include <jmorecfg.h>
+//#endif
 
 #define DO_FANCY_UPSAMPLING 0x1
 #define DO_BLOCK_SMOOTHING 0x2
@@ -31,6 +43,17 @@ extern "C" {
 
 GLOBAL(long) jround_up (long a, long b);
 
+// void error_exit (j_common_ptr cinfo)
+// {
+//   /* Always display the message */
+//   (*cinfo->err->output_message) (cinfo);
+
+//   /* Let the memory manager delete any temp files before we die */
+//   jpeg_destroy(cinfo);
+
+//   exit(EXIT_FAILURE);
+// }
+
 FILE *_read_jpeg(const char *filename,
                  struct jpeg_decompress_struct *cinfo,
                  struct jpeg_error_mgr *jerr) {
@@ -431,7 +454,7 @@ int read_jpeg_spatial(
   if(flags & QUANTIZE_COLORS) {
     cinfo.actual_number_of_colors = 256; // TODO: parametrized
     cinfo.desired_number_of_colors = 256;
-    if(in_colormap != NULL) cinfo.colormap = (unsigned char**)cmap;
+    if(in_colormap != NULL) cinfo.colormap = (char**)cmap;
   }
   
   cinfo.progressive_mode      = 0 != (flags & PROGRESSIVE_MODE);
